package com.gic.cloud.service.outer.impl;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.DataExplainDTO;
import com.gic.cloud.entity.TabDataExplain;
import com.gic.cloud.qo.DataExplainQO;
import com.gic.cloud.service.DataExplainApiService;
import com.gic.cloud.service.DataExplainService;
import com.gic.cloud.service.IndexLogService;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author zhiwj
 * @Description:
 * @date 2020-07-08 16:05
 */
@Service("dataExplainApiService")
public class DataExplainApiServiceImpl implements DataExplainApiService {

    @Autowired
    private DataExplainService dataExplainService;
    @Autowired
    private IndexLogService indexLogService;

    @Override
    public ServiceResponse<Void> saveDataExplain(DataExplainDTO dataExplainDTO) {
        // 校验参数
        if (dataExplainService.isNameRepeat(dataExplainDTO.getDataName(), null)) {
            return EnterpriseServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "数据模块名称不能重复");
        }
        // 保存
        Integer dataExplainId = dataExplainService.save(dataExplainDTO);
        dataExplainDTO.setDataExplainId(dataExplainId);
        // 日志
        indexLogService.saveDataExplainInsertLog(dataExplainDTO);

        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> updateDataExplain(DataExplainDTO dataExplainDTO, Integer updateType, String reason) {
        // 校验参数
        if (dataExplainService.isNameRepeat(dataExplainDTO.getDataName(), dataExplainDTO.getDataExplainId())) {
            return EnterpriseServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "数据模块名称不能重复");
        }
        // 保存
        dataExplainService.update(dataExplainDTO);
        // 日志
        indexLogService.saveDataExplainUpdateLog(dataExplainDTO, reason);

        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<DataExplainDTO> getByDataExplainId(Integer dataExplainId) {
        TabDataExplain dataExplain = this.dataExplainService.getByDataExplainId(dataExplainId);
        DataExplainDTO dataExplainDTO = EntityUtil.changeEntityByJSON(DataExplainDTO.class, dataExplain);
        return EnterpriseServiceResponse.success(dataExplainDTO);
    }

    @Override
    public ServiceResponse<Page<DataExplainDTO>> listDataExplain(DataExplainQO dataExplainQO) {
        com.github.pagehelper.Page<TabDataExplain> listDataExplain = this.dataExplainService.listDataExplain(dataExplainQO);
        Page<DataExplainDTO> dtoPage = PageHelperUtils.changePageHelperToCurrentPage(listDataExplain, DataExplainDTO.class);
        return EnterpriseServiceResponse.success(dtoPage);
    }
}
